========
Overview
========

Here, we present a (growing) series of working examples of how to use the cwepr package to perform both, day-to-day routine tasks in a laboratory working with cw-EPR spectroscopy as well as more complex processing and analysis tasks.

For each of the examples, a full recipe is provided ready to be copied and pasted and run on your local computer.

.. note::

    For each of the recipes provided so far, the cwepr package (at least its `repository on GitHub <https://github.com/tillbiskup/cwepr>`_) contains the real example data as well. Therefore, you can download the data and recipe to get first-hand experience with the cwepr package.


Prerequisites
=============

To be able to run the example recipes locally, you need to have a working installation of the cwepr package and its dependencies. Have a look at the :doc:`installation instructions <../installing>` for details.

Furthermore, to be able to run ("cook") the recipes and get ("serve") the results, you need to have access to a command line, as running recipes (still) is command-line based using the command :samp:`serve {recipe.yaml}`.

**Optional:** For some recipes, you will need to have a working LaTeX installation in case you would like to get your reports not only created, but compiled into a well-formatted PDF document as well.


.. note::

    The path to the data in the recipes assumes the directory layout of the cwepr package. Hence, the easiest way is to clone or download the repository from `GitHub <https://github.com/tillbiskup/cwepr>`_, change into the ``examples`` directory and there into the respective subdirectory and run the corresponding recipe.


Further examples
================

If you are interested in more examples, the :ref:`publication describing the cwepr package <sec-how_to_cite>` contains a number of examples of different complexity. The complete recipes are provided in the supporting information (SI). What is even better: You can download the entire set of data and corresponding recipes from GitHub:

* `EPR data and analysis for Schröder and Biskup, J. Magn. Reson. 335:107140, 2022 <https://github.com/tillbiskup/2022-jmr-data>`_

  GitHub repository containing both, data and recipes for all the examples shown in the :ref:`publication describing the cwepr package <sec-how_to_cite>`.